@@ -1,6 +1,6 @@
 ##############################################################################
 #
-# Copyright (c) 2002 Zope Corporation and Contributors. All Rights Reserved.
+# Copyright (c) 2002 Zope Foundation and Contributors.
 #
 # This software is subject to the provisions of the Zope Public License,
 # Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
@@ -11,17 +11,24 @@
 #
 ##############################################################################
 """Page Template module
-
-$Id: PageTemplate.py 97664 2009-03-08 13:07:59Z yuppie $
 """
+
 import sys
 import ExtensionClass
 import zope.pagetemplate.pagetemplate
-from zope.pagetemplate.pagetemplate import _error_start, PTRuntimeError
+from zope.pagetemplate.pagetemplate import PTRuntimeError
 from zope.pagetemplate.pagetemplate import PageTemplateTracebackSupplement
 from zope.tales.expressions import SimpleModuleImporter
 from Products.PageTemplates.Expressions import getEngine
 
+# Newer versions of zope.pagetemplate have this symbol as an instance method
+try:
+    from zope.pagetemplate.pagetemplate import _error_start
+except ImportError:
+    _error_start = getattr(
+        zope.pagetemplate.pagetemplate.PageTemplate, '_error_start', 
+        '<!-- Page Template Diagnostics')
+    
 
 class PageTemplate(ExtensionClass.Base,
                    zope.pagetemplate.pagetemplate.PageTemplate):
@@ -80,7 +87,10 @@ class PageTemplate(ExtensionClass.Base,
                    showtal=showtal)
 
 
-    def pt_errors(self, namespace={}):
+    def pt_errors(self, namespace={}, check_macro_expansion=None):
+        # The check_macro_expansion argument is added for
+        # compatibility with zope.pagetemplate 4.0.0.  The argument is
+        # ignored.  See LP #732972.
         self._cook_check()
         err = self._v_errors
         if err:
